@@ -164,6 +164,8 @@ autoplot.ResamplingSptCVCstf = function( # nolint
 
         data_coords = format_resampling_list(task, resampling_sub)
 
+        data_coords$indicator = NA_character_
+
         if (length(task$col_roles$time)) {
           data_coords$Date = as.Date(task$data(cols = task$col_roles$time)[[1]])
         } else {
@@ -187,13 +189,15 @@ autoplot.ResamplingSptCVCstf = function( # nolint
           data_coords = strat_sample_folds(data_coords, "test", sample_fold_n)
         }
 
-        if (show_omitted && nrow(data_coords[indicator == ""]) > 0) {
+        if (show_omitted && length(is.na(data_coords$indicator)) > 0) {
           data_coords[is.na(get("indicator")), "indicator" := "Omitted"]
 
           plot_single_plotly = plotly::plot_ly(data_coords,
             x = ~x, y = ~y, z = ~Date,
             color = ~indicator, colors = c(
-              "grey", "#E18727", "#0072B5"
+              "Omitted" = "grey",
+              "Test" = "#E18727",
+              "Train" = "#0072B5"
             ),
             sizes = c(20, 100)
           )
@@ -203,7 +207,8 @@ autoplot.ResamplingSptCVCstf = function( # nolint
           plot_single_plotly = plotly::plot_ly(data_coords,
             x = ~x, y = ~y, z = ~Date,
             color = ~indicator, colors = c(
-              "#E18727", "#0072B5"
+              "Test" = "#E18727",
+              "Train" = "#0072B5"
             ),
             sizes = c(20, 100)
           )
@@ -233,8 +238,7 @@ autoplot.ResamplingSptCVCstf = function( # nolint
           plotly::orca(plot_single_plotly, ...)
         }
 
-        print(plot_single_plotly)
-        return(invisible(plot_single_plotly))
+        return(plot_single_plotly)
       } else {
 
         ### Multiplot of multiple partitions with train and test set
@@ -243,6 +247,20 @@ autoplot.ResamplingSptCVCstf = function( # nolint
 
           data_coords = format_resampling_list(task, resampling_sub)
 
+          data_coords$indicator = NA_character_
+
+          if (length(task$col_roles$time)) {
+            data_coords$Date = as.Date(task$data(cols = task$col_roles$time)[[1]])
+          } else {
+            # if time col is not set, check for plot_time col role
+            if (!is.null(plot_time_var)) {
+              data_coords$Date = as.Date(task$data(cols = plot_time_var)[[1]])
+            } else {
+              lg$error("Neither 'time' or 'plot' column roles are set. At least one is required for 3D plotting. If the variable is only used for plotting purposes, please define argument 'plot_time_var' in `autoplot()` and remove the column role 'feature' for this variable.")
+              stop()
+            }
+          }
+
           # get test and train indices
           row_id_test = resampling_sub$instance$test[[.x]]
           row_id_train = resampling_sub$instance$train[[.x]]
@@ -259,23 +277,26 @@ autoplot.ResamplingSptCVCstf = function( # nolint
           }
 
           if (show_omitted) {
-            data_coords[indicator == "", indicator := "Omitted"]
+            data_coords[is.na(get("indicator")), "indicator" := "Omitted"]
 
             pl = plotly::plot_ly(data_coords,
               x = ~x, y = ~y, z = ~Date,
               color = ~indicator, colors = c(
-                "grey", "#E18727", "#0072B5"
+                "Omitted" = "grey",
+                "Test" = "#E18727",
+                "Train" = "#0072B5"
               ),
               #   # this is needed for later when doing 3D subplots
               scene = paste0("scene", .x),
               showlegend = ifelse(.x == 1, TRUE, FALSE)
             )
           } else {
-            data_coords = data_coords[indicator != ""]
+            data_coords[is.na(get("indicator")), "indicator" := "Omitted"]
             pl = plotly::plot_ly(data_coords,
               x = ~x, y = ~y, z = ~Date,
               color = ~indicator, colors = c(
-                "#E18727", "#0072B5"
+                "Test" = "#E18727",
+                "Train" = "#0072B5"
               ),
               #   # this is needed for later when doing 3D subplots
               scene = paste0("scene", .x),
@@ -317,7 +338,7 @@ autoplot.ResamplingSptCVCstf = function( # nolint
             paste0("scene", .x)
           )
 
-          pl = mlr3misc::invoke(plotly::layout, .args = layout_args)
+          plot = mlr3misc::invoke(plotly::layout, .args = layout_args)
 
         })
       }
@@ -343,7 +364,6 @@ autoplot.ResamplingSptCVCstf = function( # nolint
         plotly::orca(plot, ...)
       }
       return(plot)
-      return(invisible(plot))
     }
   }
 
