@@ -26,7 +26,7 @@ test_that("sptcv methods work in a Graph Learner", {
   skip_on_cran()
   skip_on_os("mac")
   skip_if_not_installed("skmeans")
-  rsmps = rsmps(c("sptcv_cstf", "sptcv_cluto"), folds = 2)
+  rsmps = rsmps(c("sptcv_cstf"), folds = 2)
 
   out = mlr3misc::map_lgl(rsmps, function(x) {
     test_graph_learner(task_cluto, x,
